Module sufr_builder

Module sufr_builder 

Create on-disk suffix/LCP arrays

Sufr builds the suffix and LCP (longest common prefix) arrays on disk. The suffixes are partitioned into temporary files, and these are sorted in parallel. Call the write method to serialized the data structures to a file (preferably with the .sufr extension) that can be read by sufr_file.

Structs

SufrBuilder
A struct for partitioning, sorting, and writing suffixes to disk